@@ -134,6 +134,7 @@ var searchData=
   ['ssh_5fget_5ferror',['ssh_get_error',['../group__libssh__error.html#ga9241586665bf21f823806473fc386258',1,'ssh_get_error(void *error):&#160;error.c'],['../group__libssh__error.html#ga9241586665bf21f823806473fc386258',1,'ssh_get_error(void *error):&#160;error.c']]],
   ['ssh_5fget_5ferror_5fcode',['ssh_get_error_code',['../group__libssh__error.html#ga036433b7bf3d4ca94206253f58d136f9',1,'ssh_get_error_code(void *error):&#160;error.c'],['../group__libssh__error.html#ga036433b7bf3d4ca94206253f58d136f9',1,'ssh_get_error_code(void *error):&#160;error.c']]],
   ['ssh_5fget_5ffd',['ssh_get_fd',['../group__libssh__session.html#gafe509fcea47714b5cd277d1e35e83276',1,'ssh_get_fd(ssh_session session):&#160;session.c'],['../group__libssh__session.html#gafe509fcea47714b5cd277d1e35e83276',1,'ssh_get_fd(ssh_session session):&#160;session.c']]],
+  ['ssh_5fget_5ffingerprint_5fhash',['ssh_get_fingerprint_hash',['../group__libssh__session.html#ga775072dc331a11b575957fe23fdd311b',1,'ssh_get_fingerprint_hash(enum ssh_publickey_hash_type type, unsigned char *hash, size_t len):&#160;dh.c'],['../group__libssh__session.html#ga775072dc331a11b575957fe23fdd311b',1,'ssh_get_fingerprint_hash(enum ssh_publickey_hash_type type, unsigned char *hash, size_t len):&#160;dh.c']]],
   ['ssh_5fget_5fhexa',['ssh_get_hexa',['../group__libssh__session.html#ga6ebcfc53884fdc5afb1607c94f8007d4',1,'ssh_get_hexa(const unsigned char *what, size_t len):&#160;dh.c'],['../group__libssh__session.html#ga6ebcfc53884fdc5afb1607c94f8007d4',1,'ssh_get_hexa(const unsigned char *what, size_t len):&#160;dh.c']]],
   ['ssh_5fget_5fhmac_5fin',['ssh_get_hmac_in',['../group__libssh__session.html#ga293196b7f1b1653ff970b8206671def9',1,'ssh_get_hmac_in(ssh_session session):&#160;session.c'],['../group__libssh__session.html#ga293196b7f1b1653ff970b8206671def9',1,'ssh_get_hmac_in(ssh_session session):&#160;session.c']]],
   ['ssh_5fget_5fhmac_5fout',['ssh_get_hmac_out',['../group__libssh__session.html#ga2fc37631d6a350d9c31dcb336b98a836',1,'ssh_get_hmac_out(ssh_session session):&#160;session.c'],['../group__libssh__session.html#ga2fc37631d6a350d9c31dcb336b98a836',1,'ssh_get_hmac_out(ssh_session session):&#160;session.c']]],
@@ -157,15 +158,20 @@ var searchData=
   ['ssh_5fis_5fblocking',['ssh_is_blocking',['../group__libssh__session.html#ga0c959bde817801ac5de2db1e64b52f26',1,'ssh_is_blocking(ssh_session session):&#160;session.c'],['../group__libssh__session.html#ga0c959bde817801ac5de2db1e64b52f26',1,'ssh_is_blocking(ssh_session session):&#160;session.c']]],
   ['ssh_5fis_5fconnected',['ssh_is_connected',['../group__libssh__session.html#ga49d8f413a3c7879070a112703de1d6e2',1,'ssh_is_connected(ssh_session session):&#160;session.c'],['../group__libssh__session.html#ga49d8f413a3c7879070a112703de1d6e2',1,'ssh_is_connected(ssh_session session):&#160;session.c']]],
   ['ssh_5fis_5fserver_5fknown',['ssh_is_server_known',['../group__libssh__session.html#ga6f37e3d7bb6b938b44d6a34a76fdfa0b',1,'ssh_is_server_known(ssh_session session):&#160;known_hosts.c'],['../group__libssh__session.html#ga6f37e3d7bb6b938b44d6a34a76fdfa0b',1,'ssh_is_server_known(ssh_session session):&#160;known_hosts.c']]],
+  ['ssh_5fkey_5falgorithm_5fallowed',['ssh_key_algorithm_allowed',['../group__libssh__pki.html#ga79010baa7b7ca9d4467910ff863e669d',1,'ssh_key_algorithm_allowed(ssh_session session, const char *type):&#160;pki.c'],['../group__libssh__pki.html#ga79010baa7b7ca9d4467910ff863e669d',1,'ssh_key_algorithm_allowed(ssh_session session, const char *type):&#160;pki.c']]],
   ['ssh_5fkey_5fclean',['ssh_key_clean',['../group__libssh__pki.html#ga9ee6aacb86cb7f4e8f3b5ec582040d3a',1,'ssh_key_clean(ssh_key key):&#160;pki.c'],['../group__libssh__pki.html#ga9ee6aacb86cb7f4e8f3b5ec582040d3a',1,'ssh_key_clean(ssh_key key):&#160;pki.c']]],
   ['ssh_5fkey_5fcmp',['ssh_key_cmp',['../group__libssh__pki.html#ga4dc33945294c2bbd671365a9d3db8e2f',1,'ssh_key_cmp(const ssh_key k1, const ssh_key k2, enum ssh_keycmp_e what):&#160;pki.c'],['../group__libssh__pki.html#ga4dc33945294c2bbd671365a9d3db8e2f',1,'ssh_key_cmp(const ssh_key k1, const ssh_key k2, enum ssh_keycmp_e what):&#160;pki.c']]],
   ['ssh_5fkey_5ffree',['ssh_key_free',['../group__libssh__pki.html#ga08808beb83a42ccd6f1c710ddeb1b4c2',1,'ssh_key_free(ssh_key key):&#160;pki.c'],['../group__libssh__pki.html#ga08808beb83a42ccd6f1c710ddeb1b4c2',1,'ssh_key_free(ssh_key key):&#160;pki.c']]],
+  ['ssh_5fkey_5fget_5fsignature_5falgorithm',['ssh_key_get_signature_algorithm',['../group__libssh__pki.html#ga7ad4109947adef7dbe7f9b8d1577cc88',1,'ssh_key_get_signature_algorithm(ssh_session session, enum ssh_keytypes_e type):&#160;pki.c'],['../group__libssh__pki.html#ga7ad4109947adef7dbe7f9b8d1577cc88',1,'ssh_key_get_signature_algorithm(ssh_session session, enum ssh_keytypes_e type):&#160;pki.c']]],
   ['ssh_5fkey_5fis_5fprivate',['ssh_key_is_private',['../group__libssh__pki.html#ga09de68aba0a7c4e31d8ba7df43b637c5',1,'ssh_key_is_private(const ssh_key k):&#160;pki.c'],['../group__libssh__pki.html#ga09de68aba0a7c4e31d8ba7df43b637c5',1,'ssh_key_is_private(const ssh_key k):&#160;pki.c']]],
   ['ssh_5fkey_5fis_5fpublic',['ssh_key_is_public',['../group__libssh__pki.html#ga9bc688b5cbc400320ac44896eba21924',1,'ssh_key_is_public(const ssh_key k):&#160;pki.c'],['../group__libssh__pki.html#ga9bc688b5cbc400320ac44896eba21924',1,'ssh_key_is_public(const ssh_key k):&#160;pki.c']]],
   ['ssh_5fkey_5fnew',['ssh_key_new',['../group__libssh__pki.html#gabfebce03474a4d014aa779d5dbf057b0',1,'ssh_key_new(void):&#160;pki.c'],['../group__libssh__pki.html#gabfebce03474a4d014aa779d5dbf057b0',1,'ssh_key_new(void):&#160;pki.c']]],
+  ['ssh_5fkey_5fsignature_5fto_5fchar',['ssh_key_signature_to_char',['../group__libssh__pki.html#ga6636345a73f0ccbc1a7dd722c5cad557',1,'ssh_key_signature_to_char(enum ssh_keytypes_e type, enum ssh_digest_e hash_type):&#160;pki.c'],['../group__libssh__pki.html#ga6636345a73f0ccbc1a7dd722c5cad557',1,'ssh_key_signature_to_char(enum ssh_keytypes_e type, enum ssh_digest_e hash_type):&#160;pki.c']]],
   ['ssh_5fkey_5ftype',['ssh_key_type',['../group__libssh__pki.html#ga9cb4a857f8e510f80cfc38e46c476490',1,'ssh_key_type(const ssh_key key):&#160;pki.c'],['../group__libssh__pki.html#ga9cb4a857f8e510f80cfc38e46c476490',1,'ssh_key_type(const ssh_key key):&#160;pki.c']]],
   ['ssh_5fkey_5ftype_5ffrom_5fname',['ssh_key_type_from_name',['../group__libssh__pki.html#ga44584f2316c6ccd40e9939454335d8bc',1,'ssh_key_type_from_name(const char *name):&#160;pki.c'],['../group__libssh__pki.html#ga44584f2316c6ccd40e9939454335d8bc',1,'ssh_key_type_from_name(const char *name):&#160;pki.c']]],
+  ['ssh_5fkey_5ftype_5ffrom_5fsignature_5fname',['ssh_key_type_from_signature_name',['../group__libssh__pki.html#ga2ef2751330c2bd09f68a14adba6b37d5',1,'ssh_key_type_from_signature_name(const char *name):&#160;pki.c'],['../group__libssh__pki.html#ga2ef2751330c2bd09f68a14adba6b37d5',1,'ssh_key_type_from_signature_name(const char *name):&#160;pki.c']]],
   ['ssh_5fkey_5ftype_5fto_5fchar',['ssh_key_type_to_char',['../group__libssh__pki.html#ga302919f046a4af504e5a2a9924b031c1',1,'ssh_key_type_to_char(enum ssh_keytypes_e type):&#160;pki.c'],['../group__libssh__pki.html#ga302919f046a4af504e5a2a9924b031c1',1,'ssh_key_type_to_char(enum ssh_keytypes_e type):&#160;pki.c']]],
+  ['ssh_5fkey_5ftype_5fto_5fhash',['ssh_key_type_to_hash',['../group__libssh__pki.html#ga10eb6e34355baea3a0dd8431188ca790',1,'ssh_key_type_to_hash(ssh_session session, enum ssh_keytypes_e type):&#160;pki.c'],['../group__libssh__pki.html#ga10eb6e34355baea3a0dd8431188ca790',1,'ssh_key_type_to_hash(ssh_session session, enum ssh_keytypes_e type):&#160;pki.c']]],
   ['ssh_5fknown_5fhosts_5fparse_5fline',['ssh_known_hosts_parse_line',['../group__libssh__session.html#gaa3a37302850d0467f19db4eba5257d3d',1,'ssh_known_hosts_parse_line(const char *host, const char *line, struct ssh_knownhosts_entry **entry):&#160;knownhosts.c'],['../group__libssh__session.html#gaa3a37302850d0467f19db4eba5257d3d',1,'ssh_known_hosts_parse_line(const char *hostname, const char *line, struct ssh_knownhosts_entry **entry):&#160;knownhosts.c']]],
   ['ssh_5fknownhosts_5fentry_5ffree',['ssh_knownhosts_entry_free',['../group__libssh__session.html#ga97b827bd9eef76277e8420359e843cd8',1,'ssh_knownhosts_entry_free(struct ssh_knownhosts_entry *entry):&#160;knownhosts.c'],['../group__libssh__session.html#ga97b827bd9eef76277e8420359e843cd8',1,'ssh_knownhosts_entry_free(struct ssh_knownhosts_entry *entry):&#160;knownhosts.c']]],
   ['ssh_5flist_5fcount',['ssh_list_count',['../group__libssh__misc.html#ga5cd8838fe4ea4b06a2b6729cf89e2415',1,'ssh_list_count(const struct ssh_list *list):&#160;misc.c'],['../group__libssh__misc.html#ga5cd8838fe4ea4b06a2b6729cf89e2415',1,'ssh_list_count(const struct ssh_list *list):&#160;misc.c']]],
@@ -187,6 +193,7 @@ var searchData=
   ['ssh_5foptions_5fset',['ssh_options_set',['../group__libssh__session.html#ga7a801b85800baa3f4e16f5b47db0a73d',1,'ssh_options_set(ssh_session session, enum ssh_options_e type, const void *value):&#160;options.c'],['../group__libssh__session.html#ga7a801b85800baa3f4e16f5b47db0a73d',1,'ssh_options_set(ssh_session session, enum ssh_options_e type, const void *value):&#160;options.c']]],
   ['ssh_5fpath_5fexpand_5ftilde',['ssh_path_expand_tilde',['../group__libssh__misc.html#ga85622306848fd7e735d5843747f6eb28',1,'ssh_path_expand_tilde(const char *d):&#160;misc.c'],['../group__libssh__misc.html#ga85622306848fd7e735d5843747f6eb28',1,'ssh_path_expand_tilde(const char *d):&#160;misc.c']]],
   ['ssh_5fpki_5fcopy_5fcert_5fto_5fprivkey',['ssh_pki_copy_cert_to_privkey',['../group__libssh__pki.html#ga71432844d5d210d63a92acff86f91e90',1,'ssh_pki_copy_cert_to_privkey(const ssh_key cert_key, ssh_key privkey):&#160;pki.c'],['../group__libssh__pki.html#ga71432844d5d210d63a92acff86f91e90',1,'ssh_pki_copy_cert_to_privkey(const ssh_key certkey, ssh_key privkey):&#160;pki.c']]],
+  ['ssh_5fpki_5fexport_5fprivkey_5fbase64',['ssh_pki_export_privkey_base64',['../group__libssh__pki.html#ga320970245fa4e3ab873888b581e13378',1,'ssh_pki_export_privkey_base64(const ssh_key privkey, const char *passphrase, ssh_auth_callback auth_fn, void *auth_data, char **b64_key):&#160;pki.c'],['../group__libssh__pki.html#ga320970245fa4e3ab873888b581e13378',1,'ssh_pki_export_privkey_base64(const ssh_key privkey, const char *passphrase, ssh_auth_callback auth_fn, void *auth_data, char **b64_key):&#160;pki.c']]],
   ['ssh_5fpki_5fexport_5fprivkey_5ffile',['ssh_pki_export_privkey_file',['../group__libssh__pki.html#ga3b294c44e2280c935cb0b82ede5c42ee',1,'ssh_pki_export_privkey_file(const ssh_key privkey, const char *passphrase, ssh_auth_callback auth_fn, void *auth_data, const char *filename):&#160;pki.c'],['../group__libssh__pki.html#ga3b294c44e2280c935cb0b82ede5c42ee',1,'ssh_pki_export_privkey_file(const ssh_key privkey, const char *passphrase, ssh_auth_callback auth_fn, void *auth_data, const char *filename):&#160;pki.c']]],
   ['ssh_5fpki_5fexport_5fprivkey_5fto_5fpubkey',['ssh_pki_export_privkey_to_pubkey',['../group__libssh__pki.html#ga5777bc537da6a447b2a9aa9eceff9877',1,'ssh_pki_export_privkey_to_pubkey(const ssh_key privkey, ssh_key *pkey):&#160;pki.c'],['../group__libssh__pki.html#ga5777bc537da6a447b2a9aa9eceff9877',1,'ssh_pki_export_privkey_to_pubkey(const ssh_key privkey, ssh_key *pkey):&#160;pki.c']]],
   ['ssh_5fpki_5fexport_5fpubkey_5fbase64',['ssh_pki_export_pubkey_base64',['../group__libssh__pki.html#ga2caa40cbd9620e9f7e3e7ab654b256c5',1,'ssh_pki_export_pubkey_base64(const ssh_key key, char **b64_key):&#160;pki.c'],['../group__libssh__pki.html#ga2caa40cbd9620e9f7e3e7ab654b256c5',1,'ssh_pki_export_pubkey_base64(const ssh_key key, char **b64_key):&#160;pki.c']]],
